~ chicken-core (chicken-5) b4dcbe354a9100cd7d1e18ff0faf075b091ee7e1


commit b4dcbe354a9100cd7d1e18ff0faf075b091ee7e1
Author:     Peter Bex <peter@more-magic.net>
AuthorDate: Mon Mar 12 17:11:22 2018 +0100
Commit:     Peter Bex <peter@more-magic.net>
CommitDate: Mon Mar 12 17:11:22 2018 +0100

    Update bootstrap script to use 5.0.0pre6

diff --git a/scripts/bootstrap.sh b/scripts/bootstrap.sh
index a0ae3c4e..fd9f99f7 100755
--- a/scripts/bootstrap.sh
+++ b/scripts/bootstrap.sh
@@ -2,18 +2,18 @@
 
 set -e
 
 # build 5.0.0pre5 development snapshot
 
-mkdir -p boot/pre5
+mkdir -p boot/pre6
 cd boot
-wget http://code.call-cc.org/dev-snapshots/2018/02/24/chicken-5.0.0pre5.tar.gz
-tar -xzf chicken-5.0.0pre5.tar.gz
-cd chicken-5.0.0pre5
-make "$@" PREFIX="$(pwd)"/../pre5
-make "$@" PREFIX="$(pwd)"/../pre5 install
+wget http://code.call-cc.org/dev-snapshots/2018/03/12/chicken-5.0.0pre6.tar.gz
+tar -xzf chicken-5.0.0pre6.tar.gz
+cd chicken-5.0.0pre6
+make "$@" PREFIX="$(pwd)"/../pre6
+make "$@" PREFIX="$(pwd)"/../pre6 install
 cd ../..
 
 # build a boot-chicken from git head using pre5 chicken and
 # then use that to build the real thing
 #
 # baf6363e535b26a67d0b9a7d71a93d8deb5de8c6 hardcodes
@@ -21,12 +21,12 @@ cd ../..
 # a boot-chicken needs to be built.
 
 make "$@" spotless
-make "$@" CHICKEN="$(pwd)"/boot/pre5/bin/chicken boot-chicken
+make "$@" CHICKEN="$(pwd)"/boot/pre6/bin/chicken boot-chicken
 
-# remove pre5 installation and tarball
-rm -fr boot/pre5
-rm -fr boot/chicken-5.0.0pre5
-rm -f  boot/chicken-5.0.0pre5.tar.gz
+# remove pre6 installation and tarball
+rm -fr boot/pre6
+rm -fr boot/chicken-5.0.0pre6
+rm -f  boot/chicken-5.0.0pre6.tar.gz
 
 echo
 echo 'Now, build chicken by passing "CHICKEN=./chicken-boot" to make,'
@@ -2,18 +2,18 @@
 set -e
 
-# build 5.0.0pre5 development snapshot
+# build 5.0.0pre6 development snapshot
 
@@ -2,18 +2,18 @@
 cd ../..
 
-# build a boot-chicken from git head using pre5 chicken and
+# build a boot-chicken from git head using pre6 chicken and
 # then use that to build the real thing
 #
Trap